@@ -143,15 +143,14 @@ c            last   - integer
 c                     number of subintervals actually produced in the
 c                     subdivision process
 C
-C            ienv   - Type (C_PTR)
-C                     array, assumed length. Passed to/from C code,
+C            ienv   - integer
+C                     array, length 2. Passed to/from C code,
 C                     not used in Fortran statements.
 c
 c***references  (none)
 c***routines called  d1mach,dqelg,dqk21,dqpsrt
 c***end prologue  dqagse
 c
-      Use ISO_C_BINDING
       double precision a,abseps,abserr,alist,area,area1,area12,area2,a1,
      *  a2,b,blist,b1,b2,correc,dabs,defabs,defab1,defab2,d1mach,dmax1,
      *  dres,elist,epmach,epsabs,epsrel,erlarg,erlast,errbnd,errmax,
@@ -159,7 +158,7 @@ c
      *  res3la,rlist,rlist2,small,uflow
       integer id,ier,ierro,iord,iroff1,iroff2,iroff3,jupbnd,k,ksgn,
      *  ktmin,last,limit,maxerr,neval,nres,nrmax,numrl2
-      Type (C_PTR) ienv
+      Integer ienv(2)
       logical extrap,noext
 c
       dimension alist(limit),blist(limit),elist(limit),iord(limit),
